/*
DS18B20数字温度传感器有别于传统的AD采集的温度传感器，
其采用单线制总线，能直接输出温度数据。
芯片介绍:
DS18x20系列数字温度传感器主要有DS18S20和DS18B20(DS18S20只有9位一种工作模式，
分辨率只到0.5摄氏度，DS18B20有9、10、11、12位四种工作可编程控制的模式，
分辨率最高为0.0625摄氏度。)，都是由美国Dallas半导体公司(现在改名叫Maxim)生产的。
这个系列最大的特点就是采用了Maxim的专利技术1-Wire。顾名思义，
1-Wire就是采用单一信号线，但可像I2C，SPI一样，同时传输时钟(clock)又传输数据(data)，
而且数据传输是双向的。1-Wire 使用较低的数据传输速率，通常是用来沟通小型device，
如数位温度计。通过1-Wire技术可以在单一信号线的基础上构成传感器网络，
Maxim起名”MicroLan”。
编程原理:
厂家已经提供可供调用的库函数，只需要把库函数拷贝下来，放到arduino\libraries下面。
这两个库函数分别是DallasTemperature和onewire两个文件夹。
本库函数有两个版本，一个支持arduino0023或以下版本编译通过，另一个支持1.01或更高版本。
*/
#include <OneWire.h>
#include <DallasTemperature.h>
#define ONE_WIRE_BUS 4 // 数据线接数据口2
OneWire oneWire(ONE_WIRE_BUS); //实例化一个对象
DallasTemperature sensors(&oneWire); //实例化一个对象
void setup(void)
{ 
  Serial.begin(115200); //串口波特率115200
  Serial.println("Dallas Temperature IC Control Library Demo");
  sensors.begin(); //调用该对象的方法，启动传感器初始化
}
void loop(void)
{
  Serial.print("Requesting temperatures...");
  sensors.requestTemperatures(); // 发送命令去读取温度
  Serial.println("DONE");
  Serial.print("Temperature for the device 1 (index 0) is: ");
  Serial.println(sensors.getTempCByIndex(0)); //显示索引号为0的传感器温度。（可在总线上接多个传感器，根据索引号地址来区分）
}
